# -*- coding: utf-8 -*-


class Options(object):
    tab: str = " " * 4
